@@ -19,6 +19,7 @@ from aicrowd.cmd import (
     login_command,
     submission_command,
     version_command,
+    notebook_command,
 )
 
 traceback.install()
@@ -32,11 +33,16 @@ LOGGING_LEVELS = {
 }  #: a mapping of `verbose` option counts to logging levels
 
 
+# pylint: disable=no-value-for-parameter
 @click.group(cls=AliasedGroup)
 @click.option("-v", "--verbose", count=True, help="Enable verbose output.")
 @click.option("--config-path", help="Path to config file", type=click.Path())
 @pass_config
-def cli(config_context: ConfigContext, verbose: int, config_path: str):
+def cli(
+    config_context: ConfigContext,
+    verbose: int,
+    config_path: str,
+):
     """
     AIcrowd CLI
     """
@@ -61,3 +67,8 @@ cli.add_command(dataset_command)
 cli.add_command(login_command)
 cli.add_command(submission_command)
 cli.add_command(version_command)
+cli.add_command(notebook_command)
+
+
+if __name__ == "__main__":
+    cli()
